@@ -1,36 +1,19 @@
 <?php
 /**
- * Implements Special:PasswordReset
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- * http://www.gnu.org/copyleft/gpl.html
- *
+ * @license GPL-2.0-or-later
  * @file
- * @ingroup SpecialPage
  */
 
 namespace MediaWiki\Specials;
 
-use ErrorPageError;
+use MediaWiki\Exception\ErrorPageError;
+use MediaWiki\Exception\ThrottledError;
 use MediaWiki\HTMLForm\HTMLForm;
 use MediaWiki\MainConfigNames;
 use MediaWiki\SpecialPage\FormSpecialPage;
 use MediaWiki\Status\Status;
 use MediaWiki\User\PasswordReset;
 use MediaWiki\User\User;
-use ThrottledError;
 
 /**
  * Special page for requesting a password reset email.
@@ -42,32 +25,20 @@ use ThrottledError;
  * @ingroup SpecialPage
  */
 class SpecialPasswordReset extends FormSpecialPage {
-	/** @var PasswordReset */
-	private $passwordReset;
+	private PasswordReset $passwordReset;
 
-	/**
-	 * @var Status
-	 */
-	private $result;
-
-	/**
-	 * @var string Identifies which password reset field was specified by the user.
-	 */
-	private $method;
-
-	/**
-	 * @param PasswordReset $passwordReset
-	 */
 	public function __construct( PasswordReset $passwordReset ) {
 		parent::__construct( 'PasswordReset', 'editmyprivateinfo' );
 
 		$this->passwordReset = $passwordReset;
 	}
 
+	/** @inheritDoc */
 	public function doesWrites() {
 		return true;
 	}
 
+	/** @inheritDoc */
 	public function userCanExecute( User $user ) {
 		return $this->passwordReset->isAllowed( $user )->isGood();
 	}
@@ -90,14 +61,16 @@ class SpecialPasswordReset extends FormSpecialPage {
 		parent::execute( $par );
 	}
 
+	/** @inheritDoc */
 	protected function getFormFields() {
 		$resetRoutes = $this->getConfig()->get( MainConfigNames::PasswordResetRoutes );
 		$a = [];
 		if ( isset( $resetRoutes['username'] ) && $resetRoutes['username'] ) {
 			$a['Username'] = [
-				'type' => 'text',
+				'type' => 'user',
 				'default' => $this->getRequest()->getSession()->suggestLoginUsername(),
 				'label-message' => 'passwordreset-username',
+				'excludetemp' => true,
 			];
 
 			if ( $this->getUser()->isRegistered() ) {
@@ -115,6 +88,7 @@ class SpecialPasswordReset extends FormSpecialPage {
 		return $a;
 	}
 
+	/** @inheritDoc */
 	protected function getDisplayFormat() {
 		return 'ooui';
 	}
@@ -141,8 +115,9 @@ class SpecialPasswordReset extends FormSpecialPage {
 	}
 
 	/**
-	 * Process the form.  At this point we know that the user passes all the criteria in
-	 * userCanExecute(), and if the data array contains 'Username', etc, then Username
+	 * Process the form.
+	 * At this point, we know that the user passes all the criteria in
+	 * userCanExecute(), and if the data array contains 'Username', etc., then Username
 	 * resets are allowed.
 	 * @param array $data
 	 * @return Status
@@ -151,44 +126,40 @@ class SpecialPasswordReset extends FormSpecialPage {
 		$username = $data['Username'] ?? null;
 		$email = $data['Email'] ?? null;
 
-		$this->method = $username ? 'username' : 'email';
-		$this->result = Status::wrap(
+		$result = Status::wrap(
 			$this->passwordReset->execute( $this->getUser(), $username, $email ) );
 
-		if ( $this->result->hasMessage( 'actionthrottledtext' ) ) {
+		if ( $result->hasMessage( 'actionthrottledtext' ) ) {
 			throw new ThrottledError;
 		}
 
-		return $this->result;
-	}
+		// Show a message on the successful processing of the form.
+		// This doesn't necessarily mean a reset email was sent.
+		if ( $result->isGood() ) {
+			$output = $this->getOutput();
 
-	/**
-	 * Show a message on the successful processing of the form.
-	 * This doesn't necessarily mean a reset email was sent.
-	 */
-	public function onSuccess() {
-		$output = $this->getOutput();
+			// Information messages.
+			$output->addWikiMsg( 'passwordreset-success' );
+			$output->addWikiMsg( 'passwordreset-success-details-generic',
+				$this->getConfig()->get( MainConfigNames::PasswordReminderResendTime ) );
 
-		// Information messages.
-		$output->addWikiMsg( 'passwordreset-success' );
-		$output->addWikiMsg( 'passwordreset-success-details-generic',
-			$this->getConfig()->get( MainConfigNames::PasswordReminderResendTime ) );
+			// Confirmation of what the user has just submitted.
+			$info = "\n";
+			if ( $username ) {
+				$info .= "* " . $this->msg( 'passwordreset-username' ) . ' '
+					. wfEscapeWikiText( $username ) . "\n";
+			}
+			if ( $email ) {
+				$info .= "* " . $this->msg( 'passwordreset-email' ) . ' '
+					. wfEscapeWikiText( $email ) . "\n";
+			}
+			$output->addWikiMsg( 'passwordreset-success-info', $info );
 
-		// Confirmation of what the user has just submitted.
-		$info = "\n";
-		$postVals = $this->getRequest()->getPostValues();
-		if ( isset( $postVals['wpUsername'] ) && $postVals['wpUsername'] !== '' ) {
-			$info .= "* " . $this->msg( 'passwordreset-username' ) . ' '
-				. wfEscapeWikiText( $postVals['wpUsername'] ) . "\n";
+			// Add a return to link to the main page.
+			$output->returnToMain();
 		}
-		if ( isset( $postVals['wpEmail'] ) && $postVals['wpEmail'] !== '' ) {
-			$info .= "* " . $this->msg( 'passwordreset-email' ) . ' '
-				. wfEscapeWikiText( $postVals['wpEmail'] ) . "\n";
-		}
-		$output->addWikiMsg( 'passwordreset-success-info', $info );
 
-		// Link to main page.
-		$output->returnToMain();
+		return $result;
 	}
 
 	/**
@@ -203,6 +174,7 @@ class SpecialPasswordReset extends FormSpecialPage {
 		return parent::isListed();
 	}
 
+	/** @inheritDoc */
 	protected function getGroupName() {
 		return 'login';
 	}
