@@ -2,16 +2,15 @@
 
 namespace MediaWiki\Tests\Parser;
 
-use CacheTime;
 use MediaWiki\MainConfigNames;
+use MediaWiki\Parser\CacheTime;
+use MediaWiki\Parser\ParserOptions;
 use MediaWiki\Utils\MWTimestamp;
 use MediaWikiIntegrationTestCase;
-use ParserOptions;
 use Wikimedia\Tests\SerializationTestTrait;
 
 /**
- * @covers \CacheTime
- * @package MediaWiki\Tests\Parser
+ * @covers \MediaWiki\Parser\CacheTime
  */
 class CacheTimeTest extends MediaWikiIntegrationTestCase {
 	use SerializationTestTrait;
@@ -26,37 +25,21 @@ class CacheTimeTest extends MediaWikiIntegrationTestCase {
 		);
 	}
 
-	/**
-	 * Overrides SerializationTestTrait::getClassToTest
-	 * @return string
-	 */
-	protected function getClassToTest(): string {
+	public static function getClassToTest(): string {
 		return CacheTime::class;
 	}
 
-	/**
-	 * Overrides SerializationTestTrait::getSerializedDataPath
-	 * @return string
-	 */
-	protected function getSerializedDataPath(): string {
+	public static function getSerializedDataPath(): string {
 		return __DIR__ . '/../../data/ParserCache';
 	}
 
-	/**
-	 * Overrides SerializationTestTrait::getTestInstancesAndAssertions
-	 * @return array
-	 */
-	protected function getTestInstancesAndAssertions(): array {
+	public static function getTestInstancesAndAssertions(): array {
 		return ParserCacheSerializationTestCases::getCacheTimeTestCases();
 	}
 
-	/**
-	 * Overrides SerializationTestTrait::getSupportedSerializationFormats
-	 * @return array
-	 */
-	protected function getSupportedSerializationFormats(): array {
+	public static function getSupportedSerializationFormats(): array {
 		return ParserCacheSerializationTestCases::getSupportedSerializationFormats(
-			$this->getClassToTest()
+			self::getClassToTest()
 		);
 	}
 
